@@ -20,10 +20,11 @@
  *  along with this program ; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  *
- * $Id: quant_matrix.c 1985 2011-05-18 09:02:35Z Isibaar $
+ * $Id: quant_matrix.c 2180 2019-11-12 14:48:35Z Isibaar $
  *
  ****************************************************************************/
 
+#include "../global.h"
 #include "quant_matrix.h"
 
 #define FIX(X)   (((X)==1) ? 0xFFFF : ((1UL << 16) / (X) + 1))
@@ -114,7 +115,7 @@ set_intra_matrix(uint16_t * mpeg_quant_matrices, const uint8_t * matrix)
 	uint16_t *intra_matrix = mpeg_quant_matrices + 0*64;
 
 	for (i = 0; i < 64; i++) {
-		intra_matrix[i] = (!i) ? (uint16_t)8: (uint16_t)matrix[i];
+		intra_matrix[i] = (!i) ? (uint16_t)8: (uint16_t)MAX(1, matrix[i]);
 	}
 }
 
@@ -141,7 +142,7 @@ set_inter_matrix(uint16_t * mpeg_quant_matrices, const uint8_t * matrix)
 	uint16_t *inter_matrix_fixl = mpeg_quant_matrices + 7*64;
 
 	for (i = 0; i < 64; i++) {
-		inter_matrix1[i] = ((inter_matrix[i] = (int16_t) matrix[i])>>1);
+		inter_matrix1[i] = ((inter_matrix[i] = (int16_t)MAX(1, (matrix[i])>>1)));
 		inter_matrix1[i] += ((inter_matrix[i] == 1) ? 1: 0);
 		inter_matrix_fix[i] = (uint16_t) FIX(inter_matrix[i]);
 		inter_matrix_fixl[i] = (uint16_t) FIXL(inter_matrix[i]);
